@@ -9,7 +9,7 @@ try:
 except LookupError:
     nltk.download('punkt')
 from nltk.tokenize import word_tokenize
-from abstract_utilities import convert_to_percentage,eatAll
+from abstract_utilities import convert_to_percentage
 from abstract_utilities.type_utils import is_number
 import tiktoken
 encoding = tiktoken.get_encoding("cl100k_base")
@@ -74,7 +74,7 @@ class PromptManager:
             chunks=['']
             for block in blocks:
                 if num_tokens_from_string(block) > max_tokens:
-                    chunks=chunks+chunk_any_to_tokens(block.split("\n"),max_tokens,delimeter="\n")
+                    chunks=chunks+chunk_any_to_tokens(block.split("\n\n"),max_tokens,delimeter="\n\n")
                 elif num_tokens_from_string(chunks[-1] + block) > max_tokens:
                     chunks.append(block)
                 else:
@@ -96,13 +96,7 @@ class PromptManager:
             else:
                 delimeter="\n\n"
                 blocks = data.split(delimeter)
-            chunks=chunk_any_to_tokens(blocks,max_tokens,delimeter)
-            new_chunks = []
-            for chunk in chunks:
-                chunk_clean=eatAll(chunk,['',' ','\n','\t','.'])
-                if len(chunk_clean)>0:
-                    new_chunks.append(chunk)
-            return new_chunks
+            return chunk_any_to_tokens(blocks,max_tokens,delimeter)
         def chunk_text_by_tokens(prompt_data, max_tokens):
             # Split prompt_data into chunks based on max_tokens
             chunks = []
